function ts = tst(L, fc, fstart, fstop, fpoints)
%
% calls an m file that calculates the frequency response of a band-pass
% filter.
% L - number of samples in the impulse response sequence
% fc - center frequency
% fstart - fstop, range of frequencies (in Hz) for which to calculate the response
% fpoints - number of values in the response array

fs = 8000; % sample frequency

f = linspace(fstart, fstop, fpoints);

HH = BPF(L, fc, fs, f);

subplot(2, 1, 1);

plot(f, abs(HH)), grid;

title('magnitude');

subplot(2, 1, 2);

plot(f, angle(HH)), grid;

title('phase');